@@ -56,6 +56,8 @@
 #include "ui_mainwindow.h"
 #include "gmic.h"
 
+bool MainWindow::_isAccepted = false;
+
 //
 // TODO : Handle window maximization properly (Windows as well as some Linux desktops)
 //
@@ -149,6 +151,11 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   ui->verticalSplitter->setStretchFactor(0, 5);
   ui->verticalSplitter->setStretchFactor(0, 1);
 
+  if (!ui->inOutSelector->hasActiveControls()) {
+    ui->vSplitterLine->hide();
+    ui->inOutSelector->hide();
+  }
+
   QPalette p = QGuiApplication::palette();
   DialogSettings::UnselectedFilterTextColor = p.color(QPalette::Disabled, QPalette::WindowText);
 
@@ -479,7 +486,7 @@ void MainWindow::makeConnections()
   connect(_filtersPresenter, SIGNAL(filterSelectionChanged()), this, SLOT(onFilterSelectionChanged()));
 
   connect(ui->pbOk, SIGNAL(clicked(bool)), this, SLOT(onOkClicked()));
-  connect(ui->pbCancel, SIGNAL(clicked(bool)), this, SLOT(onCloseClicked()));
+  connect(ui->pbCancel, SIGNAL(clicked(bool)), this, SLOT(onCancelClicked()));
   connect(ui->pbApply, SIGNAL(clicked(bool)), this, SLOT(onApplyClicked()));
   connect(ui->tbResetParameters, SIGNAL(clicked(bool)), this, SLOT(onReset()));
 
@@ -601,6 +608,7 @@ void MainWindow::onPreviewImageAvailable()
   ui->previewWidget->enableRightClick();
   ui->tbUpdateFilters->setEnabled(true);
   if (_pendingActionAfterCurrentProcessing == CloseAction) {
+    _isAccepted = false;
     close();
   }
 }
@@ -611,6 +619,7 @@ void MainWindow::onPreviewError(const QString & message)
   ui->previewWidget->enableRightClick();
   ui->tbUpdateFilters->setEnabled(true);
   if (_pendingActionAfterCurrentProcessing == CloseAction) {
+    _isAccepted = false;
     close();
   }
 }
@@ -623,6 +632,11 @@ void MainWindow::onParametersChanged()
   ui->previewWidget->sendUpdateRequest();
 }
 
+bool MainWindow::isAccepted()
+{
+  return _isAccepted;
+}
+
 void MainWindow::processImage()
 {
   // Abort any already running thread
@@ -658,6 +672,7 @@ void MainWindow::onFullImageProcessingError(const QString & message)
   QMessageBox::warning(this, tr("Error"), message, QMessageBox::Close);
   enableWidgetList(true);
   if ((_pendingActionAfterCurrentProcessing == OkAction || _pendingActionAfterCurrentProcessing == CloseAction)) {
+    _isAccepted = false;
     close();
   }
 }
@@ -692,6 +707,7 @@ void MainWindow::onFullImageProcessingDone()
   ui->filterParams->setValues(_processor.gmicStatus(), false);
   ui->filterParams->setVisibilityStates(_processor.parametersVisibilityStates());
   if ((_pendingActionAfterCurrentProcessing == OkAction || _pendingActionAfterCurrentProcessing == CloseAction)) {
+    _isAccepted = (_pendingActionAfterCurrentProcessing == OkAction);
     close();
   } else {
     // Extent cache has been cleared by the GmicProcessor
@@ -729,17 +745,20 @@ void MainWindow::onApplyClicked()
 void MainWindow::onOkClicked()
 {
   if (_filtersPresenter->currentFilter().isNoApplyFilter()) {
+    _isAccepted = _processor.completedFullImageProcessingCount();
     close();
+    return;
   }
   if (_okButtonShouldApply) {
     _pendingActionAfterCurrentProcessing = OkAction;
     processImage();
   } else {
+    _isAccepted = _processor.completedFullImageProcessingCount();
     close();
   }
 }
 
-void MainWindow::onCloseClicked()
+void MainWindow::onCancelClicked()
 {
   TIMING;
   if (_processor.isProcessing() && confirmAbortProcessingOnCloseRequest()) {
@@ -750,9 +769,11 @@ void MainWindow::onCloseClicked()
       ui->previewWidget->setOverlayMessage(tr("Waiting for cancelled jobs..."));
       _processor.cancel();
     } else {
+      _isAccepted = false;
       close();
     }
   } else {
+    _isAccepted = false;
     close();
   }
 }
@@ -1020,7 +1041,11 @@ void MainWindow::activateFilter(bool resetZoom)
     }
     ui->filterName->setText(QString("<b>%1</b>").arg(filter.name));
     ui->inOutSelector->enable();
-    ui->inOutSelector->show();
+    if (ui->inOutSelector->hasActiveControls()) {
+      ui->inOutSelector->show();
+    } else {
+      ui->inOutSelector->hide();
+    }
 
     GmicQt::InputOutputState inOutState = ParametersCache::getInputOutputState(filter.hash);
     if (inOutState.inputMode == GmicQt::UnspecifiedInputMode) {
@@ -1231,6 +1256,7 @@ void MainWindow::closeEvent(QCloseEvent * e)
     }
     e->ignore();
   } else {
+    _isAccepted = false;
     e->accept();
   }
 }
